matrix_directive = {
        "universal_id": 'matrix',
        "name": "matrix",
        "filesystem": {
            "folders": [],
            "files": {}
        },

        "children": [
        {
                "universal_id": "matrix-https",
                "name": "matrix_https",
                "delegated": [],
                "app": "matrix-core",
                "filesystem": {
                    "folders": [],
                        "files": {}
                    }
                },

            ],
}